# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/ml_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'proto/ml_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16proto/ml_service.proto\x12\x0ehome_native.v1\x1a\x1bgoogle/protobuf/empty.proto\"Q\n\x05\x45rror\x12\'\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.home_native.v1.ErrorCode\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x03 \x01(\t\"\xa4\x01\n\x06IOTask\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0binput_mimes\x18\x02 \x03(\t\x12\x14\n\x0coutput_mimes\x18\x03 \x03(\t\x12\x32\n\x06limits\x18\x04 \x03(\x0b\x32\".home_native.v1.IOTask.LimitsEntry\x1a-\n\x0bLimitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x02\n\nCapability\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x11\n\tmodel_ids\x18\x02 \x03(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x17\n\x0fmax_concurrency\x18\x04 \x01(\r\x12\x12\n\nprecisions\x18\x05 \x03(\t\x12\x34\n\x05\x65xtra\x18\x06 \x03(\x0b\x32%.home_native.v1.Capability.ExtraEntry\x12%\n\x05tasks\x18\x07 \x03(\x0b\x32\x16.home_native.v1.IOTask\x12\x18\n\x10protocol_version\x18\x08 \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\x0cInferRequest\x12\x16\n\x0e\x63orrelation_id\x18\x01 \x01(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x34\n\x04meta\x18\x04 \x03(\x0b\x32&.home_native.v1.InferRequest.MetaEntry\x12\x14\n\x0cpayload_mime\x18\x05 \x01(\t\x12\x0b\n\x03seq\x18\x06 \x01(\x04\x12\r\n\x05total\x18\x07 \x01(\x04\x12\x0e\n\x06offset\x18\x08 \x01(\x04\x1a+\n\tMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xab\x02\n\rInferResponse\x12\x16\n\x0e\x63orrelation_id\x18\x01 \x01(\t\x12\x10\n\x08is_final\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\x0c\x12\x35\n\x04meta\x18\x04 \x03(\x0b\x32\'.home_native.v1.InferResponse.MetaEntry\x12$\n\x05\x65rror\x18\x05 \x01(\x0b\x32\x15.home_native.v1.Error\x12\x0b\n\x03seq\x18\x06 \x01(\x04\x12\r\n\x05total\x18\x07 \x01(\x04\x12\x0e\n\x06offset\x18\x08 \x01(\x04\x12\x13\n\x0bresult_mime\x18\t \x01(\t\x12\x15\n\rresult_schema\x18\n \x01(\t\x1a+\n\tMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\x9f\x01\n\tErrorCode\x12\x1a\n\x16\x45RROR_CODE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45RROR_CODE_INVALID_ARGUMENT\x10\x01\x12\x1a\n\x16\x45RROR_CODE_UNAVAILABLE\x10\x02\x12 \n\x1c\x45RROR_CODE_DEADLINE_EXCEEDED\x10\x03\x12\x17\n\x13\x45RROR_CODE_INTERNAL\x10\x04\x32\xa2\x02\n\tInference\x12H\n\x05Infer\x12\x1c.home_native.v1.InferRequest\x1a\x1d.home_native.v1.InferResponse(\x01\x30\x01\x12\x45\n\x0fGetCapabilities\x12\x16.google.protobuf.Empty\x1a\x1a.home_native.v1.Capability\x12J\n\x12StreamCapabilities\x12\x16.google.protobuf.Empty\x1a\x1a.home_native.v1.Capability0\x01\x12\x38\n\x06Health\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.EmptyB\x0eZ\x0cserver/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.ml_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\014server/proto'
  _globals['_IOTASK_LIMITSENTRY']._loaded_options = None
  _globals['_IOTASK_LIMITSENTRY']._serialized_options = b'8\001'
  _globals['_CAPABILITY_EXTRAENTRY']._loaded_options = None
  _globals['_CAPABILITY_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_INFERREQUEST_METAENTRY']._loaded_options = None
  _globals['_INFERREQUEST_METAENTRY']._serialized_options = b'8\001'
  _globals['_INFERRESPONSE_METAENTRY']._loaded_options = None
  _globals['_INFERRESPONSE_METAENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCODE']._serialized_start=1144
  _globals['_ERRORCODE']._serialized_end=1303
  _globals['_ERROR']._serialized_start=71
  _globals['_ERROR']._serialized_end=152
  _globals['_IOTASK']._serialized_start=155
  _globals['_IOTASK']._serialized_end=319
  _globals['_IOTASK_LIMITSENTRY']._serialized_start=274
  _globals['_IOTASK_LIMITSENTRY']._serialized_end=319
  _globals['_CAPABILITY']._serialized_start=322
  _globals['_CAPABILITY']._serialized_end=602
  _globals['_CAPABILITY_EXTRAENTRY']._serialized_start=558
  _globals['_CAPABILITY_EXTRAENTRY']._serialized_end=602
  _globals['_INFERREQUEST']._serialized_start=605
  _globals['_INFERREQUEST']._serialized_end=839
  _globals['_INFERREQUEST_METAENTRY']._serialized_start=796
  _globals['_INFERREQUEST_METAENTRY']._serialized_end=839
  _globals['_INFERRESPONSE']._serialized_start=842
  _globals['_INFERRESPONSE']._serialized_end=1141
  _globals['_INFERRESPONSE_METAENTRY']._serialized_start=796
  _globals['_INFERRESPONSE_METAENTRY']._serialized_end=839
  _globals['_INFERENCE']._serialized_start=1306
  _globals['_INFERENCE']._serialized_end=1596
# @@protoc_insertion_point(module_scope)
